@@ -1,7 +1,7 @@
 package Text::WideChar::Util;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-07-27'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use locale;
@@ -87,7 +87,7 @@ our $re_cjk = qr/(?:
                  |   \p{Block=CJK_Unified_Ideographs_Extension_A}
                  |   \p{Block=CJK_Unified_Ideographs_Extension_B}
                      #|   \p{Block=CJK_Unified_Ideographs_Extension_C}
-                     [，。]
+                     [\N{IDEOGRAPHIC FULL STOP}\N{FULLWIDTH COMMA}]
                  )/x;
 our $re_cjk_class = qr/[
                            \p{Block=CJK_Compatibility}
@@ -100,7 +100,8 @@ our $re_cjk_class = qr/[
                            \p{Block=CJK_Unified_Ideographs}
                            \p{Block=CJK_Unified_Ideographs_Extension_A}
                            \p{Block=CJK_Unified_Ideographs_Extension_B}
-                           ，。
+                           \N{IDEOGRAPHIC FULL STOP}
+                           \N{FULLWIDTH COMMA}
                       ]/x;
 our $re_cjk_negclass = qr/[^
                               \p{Block=CJK_Compatibility}
@@ -113,7 +114,8 @@ our $re_cjk_negclass = qr/[^
                               \p{Block=CJK_Unified_Ideographs}
                               \p{Block=CJK_Unified_Ideographs_Extension_A}
                               \p{Block=CJK_Unified_Ideographs_Extension_B}
-                              ，。
+                              \N{IDEOGRAPHIC FULL STOP}
+                              \N{FULLWIDTH COMMA}
                       ]/x;
 
 sub _wrap {
@@ -416,7 +418,7 @@ Text::WideChar::Util - Routines for text containing wide characters
 
 =head1 VERSION
 
-This document describes version 0.14 of Text::WideChar::Util (from Perl distribution Text-WideChar-Util), released on 2015-01-03.
+This document describes version 0.15 of Text::WideChar::Util (from Perl distribution Text-WideChar-Util), released on 2015-07-27.
 
 =head1 SYNOPSIS
 
